@@ -1,3 +1,5 @@
+# frozen_string_literal: true
+
 require "guard/config"
 
 unless Guard::Config.new.strict?
@@ -8,8 +10,7 @@ unless Guard::Config.new.strict?
   RSpec.describe Guard::Deprecated::Evaluator do
     subject do
       class TestClass
-        def evaluate
-        end
+        def evaluate; end
       end
       described_class.add_deprecated(TestClass)
       TestClass.new
@@ -28,8 +29,8 @@ unless Guard::Config.new.strict?
       end
 
       it "displays a deprecation warning to the user" do
-        expect(Guard::UI).to receive(:deprecation).
-          with(Guard::Deprecated::Evaluator::EVALUATE_GUARDFILE)
+        expect(Guard::UI).to receive(:deprecation)
+          .with(Guard::Deprecated::Evaluator::EVALUATE_GUARDFILE)
         subject.evaluate_guardfile
       end
 
@@ -41,8 +42,8 @@ unless Guard::Config.new.strict?
 
     describe "#reevaluate_guardfile" do
       it "displays a deprecation warning to the user" do
-        expect(Guard::UI).to receive(:deprecation).
-          with(Guard::Deprecated::Evaluator::REEVALUATE_GUARDFILE)
+        expect(Guard::UI).to receive(:deprecation)
+          .with(Guard::Deprecated::Evaluator::REEVALUATE_GUARDFILE)
         subject.reevaluate_guardfile
       end
     end
